Index: /CKEditor/trunk/CHANGES.html
===================================================================
--- /CKEditor/trunk/CHANGES.html	(revision 6964)
+++ /CKEditor/trunk/CHANGES.html	(revision 6965)
@@ -46,4 +46,5 @@
 			Fixed issues:</p>
 	<ul>
+		<li><a href="http://dev.ckeditor.com/ticket/7914">#7914</a> : <strong>ATTENTION</strong> - The signature for the setReadOnly() function has been changed, reversing the meaning of the parameter to be passed to it. Please be sure to update your code on upgrade.</li>
 		<li><a href="http://dev.ckeditor.com/ticket/7657">#7657</a> : Wrong margin mirroring when creating list from RTL paragraphs.</li>
 		<li><a href="http://dev.ckeditor.com/ticket/7620">#7620</a> : Some glitch in list pasting from Microsoft Word.</li>
Index: /CKEditor/trunk/_samples/readonly.html
===================================================================
--- /CKEditor/trunk/_samples/readonly.html	(revision 6964)
+++ /CKEditor/trunk/_samples/readonly.html	(revision 6965)
@@ -1,3 +1,3 @@
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
+﻿<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
 <!--
 Copyright (c) 2003-2011, CKSource - Frederico Knabben. All rights reserved.
@@ -37,9 +37,9 @@
 	});
 
-function toggleReadOnly( makeEditable )
+function toggleReadOnly( isReadOnly )
 {
 	// Change the read-only state of the editor.
 	// http://docs.cksource.com/ckeditor_api/symbols/CKEDITOR.editor.html#setReadOnly
-	editor.setReadOnly( makeEditable );
+	editor.setReadOnly( isReadOnly );
 }
 
@@ -79,5 +79,5 @@
 		<p>
 			<input id="readOnlyOn" onclick="toggleReadOnly();" type="button" value="Make it read-only" style="display:none" />
-			<input id="readOnlyOff" onclick="toggleReadOnly( true );" type="button" value="Make it editable again" style="display:none" />
+			<input id="readOnlyOff" onclick="toggleReadOnly( false );" type="button" value="Make it editable again" style="display:none" />
 		</p>
 	</form>
Index: /CKEditor/trunk/_source/core/editor.js
===================================================================
--- /CKEditor/trunk/_source/core/editor.js	(revision 6964)
+++ /CKEditor/trunk/_source/core/editor.js	(revision 6965)
@@ -734,13 +734,15 @@
 		 * the editor, firing the "readOnly" event.<br><br>
 		 * <strong>Note:</strong> the current editing area will be reloaded.
 		 * @param {Boolean} [makeEditable] Indicates that the editor must be
 		 *		restored from read-only mode, making it editable.
 		 * @since 3.6
 		 */
-		setReadOnly : function( makeEditable )
-		{
-			if ( this.readOnly != !makeEditable )
-			{
-				this.readOnly = !makeEditable;
+		setReadOnly : function( isReadOnly )
+		{
+			isReadOnly = ( isReadOnly == undefined ) || isReadOnly;
+
+			if ( this.readOnly != isReadOnly )
+			{
+				this.readOnly = isReadOnly;
 
 				// Fire the readOnly event so the editor features can update
@@ -734,13 +734,15 @@
 		 * the editor, firing the "readOnly" event.<br><br>
 		 * <strong>Note:</strong> the current editing area will be reloaded.
-		 * @param {Boolean} [makeEditable] Indicates that the editor must be
-		 *		restored from read-only mode, making it editable.
+		 * @param {Boolean} [isReadOnly] Indicates that the editor must go
+		 *		read-only (true, default) or be restored and made editable (false).
 		 * @since 3.6
 		 */
